@@ -383,7 +383,7 @@ For generic functions, describe all the methods."
                  (spinneret:with-html-string
                    (:pre (:code (:raw (resolve-backtick-quote-links (documentation input 'function) (symbol-package input)))))
                    (when (sym:command-symbol-p input)
-                     (let* ((key-keymap-pairs (nth-value 1 (keymaps:binding-keys input (all-keymaps))))
+                     (let* ((key-keymap-pairs (nth-value 1 (keymaps:pretty-binding-keys input (all-keymaps) :print-style (keymaps:name (keyscheme buffer)))))
                             (key-keymapname-pairs (mapcar (lambda (pair)
                                                             (list (first pair)
                                                                   (keymaps:name (second pair))))
@@ -629,14 +629,12 @@ A command is a special kind of function that can be called with
                          (:h3 (keymaps:name keymap))
                          (:table
                           (:tr
-                           (:th "Binding")
                            (:th "Command")
                            (:th "Documentation"))
                           (loop for keyspec being the hash-keys
                                   in (keymaps:keymap-with-parents->map keymap)
                                     using (hash-value bound-value)
                                 collect (:tr
-                                         (:td keyspec)
                                          (:td (typecase bound-value
                                                 (sym:command-symbol (:nxref :command bound-value))
                                                 (command (:nxref :command (name bound-value)))
@@ -647,7 +645,7 @@ A command is a special kind of function that can be called with
       (:p (format nil "Buffer with ID ~a does not exist." id)))))
 
 (define-command-global describe-bindings (&key (buffer (current-buffer)))
-  "Show a buffer with the list of all known bindings for the current buffer."
+  "Show a buffer with the list of all known key bindings for the current buffer."
   (buffer-load-internal-page-focus 'describe-bindings :id (id buffer)))
 
 (defun describe-key-dispatch (command)
@@ -722,7 +720,7 @@ A command is a special kind of function that can be called with
                          based features are currently unlisted.")
                      (:h1 "Commands")))
     (format f "~a" (spinneret:with-html-string
-                     (:nstyle (lass:compile-and-write '(.nyxt-source :overflow auto)))))
+                     (:nstyle '(.nyxt-source :overflow auto))))
     (format f "~{~a ~%~}"
             (loop for command in (list-commands)
                   collect (spinneret:with-html-string
