@@ -69,6 +69,16 @@ define which elements are picked up by element hinting.
 For instance, to include images:
 
     a, button, input, textarea, details, select, img:not([alt=\"\"])")
+   (hints-offset-x
+    0
+    :type integer
+    :documentation "The number of pixels that hint overlays are horizontally shifted by.
+A positive value shifts to the right.")
+   (hints-offset-y
+    0
+    :type integer
+    :documentation "The number of pixels that hint overlays are vertically shifted by.
+A positive value shifts to the bottom.")
    (keyscheme-map
     (define-keyscheme-map "hint-mode" ()
       keyscheme:cua
@@ -97,29 +107,40 @@ For instance, to include images:
        "g f" 'follow-hint-nosave-buffer
        "g F" 'follow-hint-nosave-buffer-focus)))))
 
-(define-parenscript-async hint-elements (hints)
+(define-parenscript-async hint-elements (hints nyxt-identifiers)
   (defun create-hint-overlay (original-element hint)
     "Create a DOM element to be used as a hint."
-    (ps:let* ((rect (ps:chain original-element (get-bounding-client-rect)))
-              (element (ps:chain document (create-element "span"))))
-      (setf (ps:@ element class-name) "nyxt-hint")
-      (setf (ps:@ element style position) "absolute")
-      (setf (ps:@ element style left) (+ (ps:@ window page-x-offset) (ps:@ rect left) "px"))
-      (setf (ps:@ element style top) (+ (ps:@ window page-y-offset) (ps:@ rect top) "px"))
-      (setf (ps:@ element id) (+ "nyxt-hint-" hint))
-      (setf (ps:@ element text-content) hint)
+    (ps:let ((user-x-offset (ps:lisp (hints-offset-x (find-submode 'hint-mode))))
+             (user-y-offset (ps:lisp (hints-offset-y (find-submode 'hint-mode))))
+             (rect (ps:chain original-element (get-bounding-client-rect)))
+             (element (ps:chain document (create-element "span"))))
+      (setf (ps:@ element class-name) "nyxt-hint"
+            (ps:@ element style position) "absolute"
+            (ps:@ element style left) (+ (ps:max (+ (ps:@ window page-x-offset)
+                                                    (ps:@ rect left)
+                                                    user-x-offset)
+                                                 0)
+                                         "px")
+            (ps:@ element style top) (+ (ps:max (+ (ps:@ window page-y-offset)
+                                                   (ps:@ rect top)
+                                                   user-y-offset)
+                                                0)
+                                        "px")
+            (ps:@ element id) (+ "nyxt-hint-" hint)
+            (ps:@ element text-content) hint)
       element))
 
   (let ((fragment (ps:chain document (create-document-fragment)))
         (hints (ps:lisp (list 'quote hints)))
-        (i 0))
-    (dolist (element (nyxt/ps:qsa document "[nyxt-hintable]"))
-      (let ((hint (aref hints i)))
+        (nyxt-identifiers (ps:lisp (list 'quote nyxt-identifiers))))
+    (dotimes (i (length hints))
+      (let* ((hint (aref hints i))
+             (nyxt-identifier (aref nyxt-identifiers i))
+             (element (nyxt/ps:rqs-nyxt-id document nyxt-identifier)))
         (ps:chain element (set-attribute "nyxt-hint" hint))
         (ps:chain fragment (append-child (create-hint-overlay element hint)))
         (when (ps:lisp (show-hint-scope-p (find-submode 'hint-mode)))
-          (ps:chain element class-list (add "nyxt-element-hint")))
-        (setf i (1+ i))))
+          (ps:chain element class-list (add "nyxt-element-hint")))))
     (ps:chain document body (append-child fragment))
     ;; Returning fragment makes WebKit choke.
     nil))
@@ -149,7 +170,7 @@ For instance, to include images:
                                            alphabet))))))
 
 (define-parenscript set-hintable-attribute (selector)
-  (let ((elements (nyxt/ps:qsa document (ps:lisp selector)))
+  (let ((elements (nyxt/ps:rqsa document (ps:lisp selector)))
         (in-view-port-p (ps:lisp (eq :vi (hinting-type (find-submode 'hint-mode))))))
     (ps:dolist (element elements)
       (if in-view-port-p
@@ -158,7 +179,7 @@ For instance, to include images:
           (ps:chain element (set-attribute "nyxt-hintable" ""))))))
 
 (define-parenscript remove-hintable-attribute ()
-  (ps:dolist (element (nyxt/ps:qsa document "[nyxt-hintable]"))
+  (ps:dolist (element (nyxt/ps:rqsa document "[nyxt-hintable]"))
     (ps:chain element (remove-attribute "nyxt-hintable"))))
 
 (defun add-hints (&key selector (buffer (current-buffer)))
@@ -169,17 +190,19 @@ For instance, to include images:
   (update-document-model :buffer buffer)
   (let* ((hintable-elements (clss:select "[nyxt-hintable]" (document-model buffer)))
          (hints (generate-hints (length hintable-elements))))
-    (hint-elements hints)
     (loop for elem across hintable-elements
           for hint in hints
           do (plump:set-attribute elem "nyxt-hint" hint)
-          collect elem)))
+          collect elem
+          finally (hint-elements hints (map 'list #'(lambda (elem)
+                                                      (plump:attribute elem "nyxt-identifier"))
+                                            hintable-elements)))))
 
 (define-parenscript-async remove-hint-elements ()
-  (ps:dolist (element (nyxt/ps:qsa document ":not(.nyxt-search-node) > .nyxt-hint"))
+  (ps:dolist (element (nyxt/ps:rqsa document ":not(.nyxt-search-node) > .nyxt-hint"))
     (ps:chain element (remove)))
   (when (ps:lisp (show-hint-scope-p (find-submode 'hint-mode)))
-    (ps:dolist (element (nyxt/ps:qsa document ".nyxt-element-hint"))
+    (ps:dolist (element (nyxt/ps:rqsa document ".nyxt-element-hint"))
       (ps:chain element class-list (remove "nyxt-element-hint")))))
 
 (defun remove-hints (&key (buffer (current-buffer)))
@@ -188,11 +211,15 @@ For instance, to include images:
   (update-document-model :buffer buffer))
 
 (export-always 'identifier)
-(defmethod identifier ((element plump:element))
+(define-generic identifier ((element plump:element))
+  "ELEMENT's on-page identifier (constructed from `hint-alphabet' characters.)"
   (plump:attribute element "nyxt-hint"))
 
 (export-always 'highlight-selected-hint)
 (define-parenscript highlight-selected-hint (&key element scroll)
+  ;; TODO: Also change border or something else to augment color change.
+  "Accent the hint for the ELEMENT to be distinguishable from other hints.
+If SCROLL (default to NIL), scroll the hint into view."
   (let ((%element (nyxt/ps:qs document (ps:lisp (format nil "#nyxt-hint-~a"
                                                         (identifier element))))))
     (when %element
